@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2004-2005, 2007-2008, 2010-2012 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -77,7 +76,8 @@ imap4d_close0 (struct imap4d_command *command, imap4d_tokbuf_t tok,
       EXPUNGE responses are sent. */
 
 int
-imap4d_close (struct imap4d_command *command, imap4d_tokbuf_t tok)
+imap4d_close (struct imap4d_session *session,
+              struct imap4d_command *command, imap4d_tokbuf_t tok)
 {
   return imap4d_close0 (command, tok, 1);
 }
@@ -101,7 +101,8 @@ imap4d_close (struct imap4d_command *command, imap4d_tokbuf_t tok)
       selected mailbox.
 */
 int
-imap4d_unselect (struct imap4d_command *command, imap4d_tokbuf_t tok)
+imap4d_unselect (struct imap4d_session *session,
+                 struct imap4d_command *command, imap4d_tokbuf_t tok)
 {
   return imap4d_close0 (command, tok, 0);
 }
