@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2020 Free Software Foundation, Inc.
+   Copyright (C) 2009-2022 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -64,9 +64,14 @@ int mu_c_str_unescape_trans (char const *str, char const *trans,
 			     char **ret_str);
 
 
+int mu_version_string_parse (char const *verstr, int version[3], char **endp);
+int mu_version_string_cmp (char const *a, char const *b, int ignoresuf, int *res);
+  
 int mu_str_expand (char **output, char const *input, mu_assoc_t assoc);
 int mu_str_vexpand (char **output, char const *input, ...);
-  
+
+int mu_strtosize (char const *str, char **endp, size_t *ret_val);
+
 #ifdef __cplusplus
 }
 #endif
