@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2008-2012, 2014-2016 Free Software Foundation, Inc.
+   Copyright (C) 2008-2022 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -63,6 +63,9 @@ int mu_opool_union (mu_opool_t *dst, mu_opool_t *src);
    begin a new object. */
 void mu_opool_clear (mu_opool_t opool);
 
+/* Reset the length of the current object to SIZE bytes */
+void mu_opool_less (mu_opool_t opool, size_t size);
+
 /* Free object OBJ from the pool.  If OBJ is NULL, free all created objects,
    including the one being built */
 void mu_opool_free (mu_opool_t pool, void *obj);
