@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -135,10 +135,19 @@ struct mu_content_type
 };
 
 typedef struct mu_content_type *mu_content_type_t;
-  
+ 
+#define MU_CONTENT_TYPE_STRICT   0x00 
+#define MU_CONTENT_TYPE_RELAXED  0x01
+#define MU_CONTENT_TYPE_PARAM    0x02
+
 int mu_content_type_parse (const char *input, const char *charset,
 			   mu_content_type_t *retct);
+int mu_content_type_parse_ext (const char *input, const char *charset,
+			       int flags,
+			       mu_content_type_t *retct);
 void mu_content_type_destroy (mu_content_type_t *pptr);
+
+int mu_content_type_format (mu_content_type_t ct, char **return_ptr);
   
   /* ----------------------- */
   /* Filter+iconv            */
@@ -182,6 +191,7 @@ enum mu_c_type
     mu_c_long,
     mu_c_ulong,
     mu_c_size,
+    mu_c_hsize,       /* mu_c_size with size suffix (KMG) allowed */
     mu_c_off,
     mu_c_time,
     mu_c_bool,
@@ -238,6 +248,9 @@ int mu_remove_file (const char *path);
 int mu_file_name_is_safe (char const *str);
   
 int mu_getmaxfd (void);
+void mu_close_fds (int minfd);
+int mu_daemon (void);
+  
 /* Get the host name, doing a gethostbyname() if possible. */
 int mu_get_host_name (char **host);
 int mu_spawnvp (const char *prog, char *av[], int *stat);
