@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2004-2005, 2007-2008, 2010-2012, 2014-2016
-   Free Software Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -29,7 +28,9 @@ mu_list_foreach (mu_list_t list, mu_list_action_t action, void *cbdata)
   mu_iterator_t itr;
   int status = 0;
 
-  if (list == NULL || action == NULL)
+  if (list == NULL)
+    return 0;
+  if (action == NULL)
     return EINVAL;
   status = mu_list_get_iterator (list, &itr);
   if (status)
@@ -45,11 +46,3 @@ mu_list_foreach (mu_list_t list, mu_list_action_t action, void *cbdata)
   mu_iterator_destroy (&itr);
   return status;
 }
-
-/* Retained for compatibility with previous versions.
-   In the future it will be removed, or changed to a define or weak alias. */
-int
-mu_list_do (mu_list_t list, mu_list_action_t action, void *cbdata)
-{
-  return mu_list_foreach (list, action, cbdata);
-}
