@@ -155,23 +155,14 @@ static void
 capture_last_char (char *buf, size_t size, void *data)
 {
   int *n = data;
-  if (buf[size-1] == '\n')
-    {
-      if (size == 1)
-	{
-	  ++*n;
-	}
-      else if (buf[size-2] == '\n')
-	*n = 2;
-      else
-	*n = 1;
-    }
-  else
-    *n = 0;
+  *n = (buf[size-1] == '\n');
 }
 
-/* Same as mu_stream_copy, but also ensures that the copied data end with
-   two '\n' characters. */
+/*
+ * Copies data from SRC to DST, appending an empty line (single newline) at
+ * the end.  If data in SRC does not end in a newline character, an additional
+ * newline is appended.
+ */
 int
 mu_stream_copy_nl (mu_stream_t dst, mu_stream_t src, mu_off_t size,
 		   mu_off_t *pcsz)
@@ -179,11 +170,11 @@ mu_stream_copy_nl (mu_stream_t dst, mu_stream_t src, mu_off_t size,
   int lc = 0;
   int status = mu_stream_copy_wcb (dst, src, size, capture_last_char, &lc,
 				   pcsz);
-  if (status == 0 && lc < 2)
+  if (status == 0)
     {
       status = mu_stream_write (dst, "\n\n", 2 - lc, NULL);
       if (status == 0 && pcsz)
-	++ *pcsz;
+	*pcsz += 2 - lc;
     }
   return status;
 }
