@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2012, 2014-2017 Free Software Foundation, Inc.
+   Copyright (C) 2009-2022 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -100,5 +100,5 @@ mu_temp_file_stream_create (mu_stream_t *pstream,
 	  *pstream = stream;
 	}
     }
-  return 0;
+  return rc;
 }
