@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2021 Free Software Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -59,11 +59,20 @@ append_to_mailbox (mu_url_t url, msgset_t *msglist, int mark,
 
   for (mp = msglist; mp; mp = mp->next)
     {
+      mu_attribute_t atr;
+      
       status = util_get_message (mbox, msgset_msgno (mp), &msg);
       if (status)
 	break;
 
-      status = mu_mailbox_append_message (mbx, msg);
+      status = mu_message_get_attribute (msg, &atr);
+      if (status)
+	{
+	  mu_diag_funcall (MU_DIAG_WARNING, "mu_message_get_attribute", NULL,
+			   status);
+	  atr = NULL;
+	}
+      status = mu_mailbox_append_message_ext (mbx, msg, NULL, atr);
       if (status)
 	{
 	  mu_error (_("Cannot append message: %s"), mu_strerror (status));
@@ -97,6 +106,10 @@ append_to_file (char const *filename, msgset_t *msglist, int mark,
   mu_stream_t ostr, mstr;
   mu_message_t msg;
   mu_locker_t locker;
+  mu_locker_hints_t hints = {
+    .flags = MU_LOCKER_FLAG_TYPE | MU_LOCKER_FLAG_RETRY,
+    .type = MU_LOCKER_TYPE_KERNEL
+  };
   mu_stream_stat_buffer stat;
 
   status = mu_file_stream_create (&ostr, filename,
@@ -108,8 +121,7 @@ append_to_file (char const *filename, msgset_t *msglist, int mark,
       return 1;
     }
 
-  status = mu_locker_create (&locker, filename,
-			     MU_LOCKER_KERNEL|MU_LOCKER_RETRY);
+  status = mu_locker_create_ext (&locker, filename, &hints);
   if (status)
     {
       mu_error (_("Cannot create locker %s: %s"),
@@ -220,13 +232,21 @@ mail_copy0 (int argc, char **argv, int mark)
   msgset_t *msglist = NULL;
   struct append_stat totals = { 0, 0 };
   int rc;
-  char *filename;
-
+  char *filename, *storage = NULL;
+  
   if (mu_isupper (argv[0][0]))
     {
       if (msgset_parse (argc, argv, MSG_NODELETED, &msglist))
 	return 1;
-      filename = util_outfolder_name (util_get_sender (msgset_msgno (msglist), 1));
+      storage = util_get_sender (msgset_msgno (msglist), 1);
+      filename = util_outfolder_name (storage);
+      if (filename)
+	{
+	  free (storage);
+	  storage = filename;
+	}
+      else
+	filename = storage;
     }
   else
     {
@@ -235,19 +255,22 @@ mail_copy0 (int argc, char **argv, int mark)
 	return 1;
     }
 
-  if (mail_expand_name (filename, &url))
-    return 1;
-  filename = (char*) mu_url_to_string (url);
-  if (mu_url_is_scheme (url, "file") || mu_url_is_scheme (url, "mbox"))
-    rc = append_to_file (filename, msglist, mark, &totals);
-  else
-    rc = append_to_mailbox (url, msglist, mark, &totals);
+  rc = mail_expand_name (filename, &url);
   if (rc == 0)
-    mu_printf ("\"%s\" %3lu/%-5lu\n", filename,
-	       (unsigned long) totals.lines, (unsigned long) totals.size);
-  mu_url_destroy (&url);
+    {
+      filename = (char*) mu_url_to_string (url);
+      if (mu_url_is_scheme (url, "file") || mu_url_is_scheme (url, "mbox"))
+	rc = append_to_file (filename, msglist, mark, &totals);
+      else
+	rc = append_to_mailbox (url, msglist, mark, &totals);
+      if (rc == 0)
+	mu_printf ("\"%s\" %3lu/%-5lu\n", filename,
+		   (unsigned long) totals.lines, (unsigned long) totals.size);
+      mu_url_destroy (&url);
+    }
+  free (storage);
   msgset_free (msglist);
-  return 0;
+  return rc;
 }
 
 int
