@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2021 Free Software Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,7 +34,8 @@ mail_write (int argc, char **argv)
 
   if (mu_isupper (argv[0][0]))
     {
-      if (msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT, &msglist))
+      if (msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT|MSG_ALLOWPART,
+			&msglist))
 	return 1;
       filename = namebuf = util_get_sender (msgset_msgno (msglist), 1);
     }
@@ -55,7 +56,8 @@ mail_write (int argc, char **argv)
 	  mu_asprintf (&namebuf, "%lu", (unsigned long) n);
 	  filename = namebuf;
 	}
-      if (msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT, &msglist))
+      if (msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT|MSG_ALLOWPART,
+			&msglist))
 	return 1;
     }
   
