@@ -58,14 +58,23 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
+/* Substitute the type names.  */
+#define YYSTYPE         PICK_YYSTYPE
+/* Substitute the variable and function names.  */
+#define yyparse         pick_yyparse
+#define yylex           pick_yylex
+#define yyerror         pick_yyerror
+#define yydebug         pick_yydebug
+#define yynerrs         pick_yynerrs
 
-
+#define yylval          pick_yylval
+#define yychar          pick_yychar
 
 /* Copy the first part of user declarations.  */
 #line 1 "pick-gram.y" /* yacc.c:339  */
 
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2021 Free Software Foundation, Inc.
+   Copyright (C) 2003-2022 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -95,14 +104,14 @@ regex_dup (regex_t *re)
   return rp;
 }
 
-int pick_yyerror (const char *s);
-int pick_yylex (void); 
+int yyerror (const char *s);
+int yylex (void); 
  
 static node_t *parse_tree;
 static int nesting_level;
 static int reg_flags = REG_EXTENDED|REG_ICASE;
 
-#line 106 "pick-gram.c" /* yacc.c:339  */
+#line 115 "pick-gram.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -121,21 +130,37 @@ static int reg_flags = REG_EXTENDED|REG_ICASE;
 #endif
 
 /* In a future release of Bison, this section will be replaced
-   by #include "y.tab.h".  */
-#ifndef YY_YY_Y_TAB_H_INCLUDED
-# define YY_YY_Y_TAB_H_INCLUDED
+   by #include "pick-gram.h".  */
+#ifndef YY_PICK_YY_PICK_GRAM_H_INCLUDED
+# define YY_PICK_YY_PICK_GRAM_H_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
+#ifndef PICK_YYDEBUG
+# if defined YYDEBUG
 #if YYDEBUG
+#   define PICK_YYDEBUG 1
+#  else
+#   define PICK_YYDEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define PICK_YYDEBUG 1
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined PICK_YYDEBUG */
+#if PICK_YYDEBUG
 extern int pick_yydebug;
 #endif
+/* "%code requires" blocks.  */
+#line 42 "pick-gram.y" /* yacc.c:355  */
+
+#define PICK_YYLTYPE struct mu_locus_range
+#define yylloc pick_yylloc
+#define yylval pick_yylval
+
+#line 159 "pick-gram.c" /* yacc.c:355  */
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef PICK_YYTOKENTYPE
+# define PICK_YYTOKENTYPE
+  enum pick_yytokentype
   {
     T_COMP = 258,
     T_DATEFIELD = 259,
@@ -150,48 +175,36 @@ extern int pick_yydebug;
     T_NOT = 268
   };
 #endif
-/* Tokens.  */
-#define T_COMP 258
-#define T_DATEFIELD 259
-#define T_STRING 260
-#define T_CFLAGS 261
-#define T_LBRACE 262
-#define T_RBRACE 263
-#define T_BEFORE 264
-#define T_AFTER 265
-#define T_OR 266
-#define T_AND 267
-#define T_NOT 268
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+#if ! defined PICK_YYSTYPE && ! defined PICK_YYSTYPE_IS_DECLARED
 
-union YYSTYPE
+union PICK_YYSTYPE
 {
-#line 47 "pick-gram.y" /* yacc.c:355  */
+#line 54 "pick-gram.y" /* yacc.c:355  */
 
   char *string;
   node_t *node;
   regex_t regex;
 
-#line 178 "pick-gram.c" /* yacc.c:355  */
+#line 191 "pick-gram.c" /* yacc.c:355  */
 };
 
-typedef union YYSTYPE YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+typedef union PICK_YYSTYPE PICK_YYSTYPE;
+# define PICK_YYSTYPE_IS_TRIVIAL 1
+# define PICK_YYSTYPE_IS_DECLARED 1
 #endif
 
 
-extern YYSTYPE pick_yylval;
+extern PICK_YYSTYPE pick_yylval;
 
 int pick_yyparse (void);
 
-#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
+#endif /* !YY_PICK_YY_PICK_GRAM_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-#line 195 "pick-gram.c" /* yacc.c:358  */
+#line 208 "pick-gram.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -283,7 +296,7 @@ typedef short int yytype_int16;
 #endif
 
 #if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
-/* Suppress an incorrect diagnostic about pick_yylval being uninitialized.  */
+/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
     _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")\
@@ -372,17 +385,17 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined PICK_YYSTYPE_IS_TRIVIAL && PICK_YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
-union pick_yyalloc
+union yyalloc
 {
   yytype_int16 yyss_alloc;
   YYSTYPE yyvs_alloc;
 };
 
 /* The size of the maximum gap between one aligned stack and the next.  */
-# define YYSTACK_GAP_MAXIMUM (sizeof (union pick_yyalloc) - 1)
+# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
 
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
@@ -445,7 +458,7 @@ union pick_yyalloc
 #define YYNSTATES  29
 
 /* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by pick_yylex, with out-of-bounds checking.  */
+   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   268
 
@@ -453,7 +466,7 @@ union pick_yyalloc
   ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by pick_yylex, without out-of-bounds checking.  */
+   as returned by yylex, without out-of-bounds checking.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -485,16 +498,16 @@ static const yytype_uint8 yytranslate[] =
        5,     6,     7,     8,     9,    10,    11,    12,    13
 };
 
-#if YYDEBUG
+#if PICK_YYDEBUG
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    59,    59,    62,    68,    69,    75,    76,    82,    96,
-     100,   104,   108,   112,   123,   134,   138,   142,   148,   154
+       0,    66,    66,    69,    75,    76,    82,    83,    89,   103,
+     107,   111,   115,   119,   130,   141,   145,   149,   155,   161
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || 0
+#if PICK_YYDEBUG || YYERROR_VERBOSE || 0
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -528,7 +541,7 @@ static const yytype_uint16 yytoknum[] =
 
   /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
      STATE-NUM.  */
-static const yytype_int8 pick_yypact[] =
+static const yytype_int8 yypact[] =
 {
       13,    -7,    -7,    -7,     3,     7,    29,    18,    21,     6,
       -7,    32,    29,    -7,    -7,    -7,    -7,    32,    23,    -7,
@@ -560,7 +573,7 @@ static const yytype_int8 yydefgoto[] =
   /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
      positive, shift that token.  If negative, reduce the rule whose
      number is the opposite.  If YYTABLE_NINF, syntax error.  */
-static const yytype_int8 pick_yytable[] =
+static const yytype_int8 yytable[] =
 {
       15,     1,    17,     2,     3,    27,     4,     5,    13,    18,
        6,    19,    14,    -2,    25,    26,    17,     1,    16,     2,
@@ -569,7 +582,7 @@ static const yytype_int8 pick_yytable[] =
       23,     0,     6,    20,    21,    24
 };
 
-static const yytype_int8 pick_yycheck[] =
+static const yytype_int8 yycheck[] =
 {
        6,     4,     8,     6,     7,     8,     9,    10,     5,     3,
       13,     5,     5,     0,    20,    21,    22,     4,     0,     6,
@@ -588,14 +601,14 @@ static const yytype_uint8 yystos[] =
 };
 
   /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
-static const yytype_uint8 pick_yyr1[] =
+static const yytype_uint8 yyr1[] =
 {
        0,    14,    15,    15,    16,    16,    17,    17,    18,    19,
       19,    19,    19,    19,    19,    19,    19,    19,    20,    21
 };
 
   /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
-static const yytype_uint8 pick_yyr2[] =
+static const yytype_uint8 yyr2[] =
 {
        0,     2,     0,     1,     1,     2,     0,     1,     2,     3,
        3,     1,     1,     2,     2,     3,     3,     2,     1,     1
@@ -603,7 +616,7 @@ static const yytype_uint8 pick_yyr2[] =
 
 
 #define yyerrok         (yyerrstatus = 0)
-#define yyclearin       (pick_yychar = YYEMPTY)
+#define yyclearin       (yychar = YYEMPTY)
 #define YYEMPTY         (-2)
 #define YYEOF           0
 
@@ -616,17 +629,17 @@ static const yytype_uint8 pick_yyr2[] =
 
 #define YYBACKUP(Token, Value)                                  \
 do                                                              \
-  if (pick_yychar == YYEMPTY)                                        \
+  if (yychar == YYEMPTY)                                        \
     {                                                           \
-      pick_yychar = (Token);                                         \
-      pick_yylval = (Value);                                         \
-      YYPOPSTACK (pick_yylen);                                       \
-      pick_yystate = *yyssp;                                         \
+      yychar = (Token);                                         \
+      yylval = (Value);                                         \
+      YYPOPSTACK (yylen);                                       \
+      yystate = *yyssp;                                         \
       goto yybackup;                                            \
     }                                                           \
   else                                                          \
     {                                                           \
-      pick_yyerror (YY_("syntax error: cannot back up")); \
+      yyerror (YY_("syntax error: cannot back up")); \
       YYERROR;                                                  \
     }                                                           \
 while (0)
@@ -638,7 +651,7 @@ while (0)
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if PICK_YYDEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -647,7 +660,7 @@ while (0)
 
 # define YYDPRINTF(Args)                        \
 do {                                            \
-  if (pick_yydebug)                                  \
+  if (yydebug)                                  \
     YYFPRINTF Args;                             \
 } while (0)
 
@@ -659,7 +672,7 @@ do {                                            \
 
 # define YY_SYMBOL_PRINT(Title, Type, Value, Location)                    \
 do {                                                                      \
-  if (pick_yydebug)                                                            \
+  if (yydebug)                                                            \
     {                                                                     \
       YYFPRINTF (stderr, "%s ", Title);                                   \
       yy_symbol_print (stderr,                                            \
@@ -721,7 +734,7 @@ yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 
 # define YY_STACK_PRINT(Bottom, Top)                            \
 do {                                                            \
-  if (pick_yydebug)                                                  \
+  if (yydebug)                                                  \
     yy_stack_print ((Bottom), (Top));                           \
 } while (0)
 
@@ -731,13 +744,13 @@ do {                                                            \
 `------------------------------------------------*/
 
 static void
-yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int pick_yyrule)
+yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
 {
-  unsigned long int yylno = yyrline[pick_yyrule];
-  int yynrhs = pick_yyr2[pick_yyrule];
+  unsigned long int yylno = yyrline[yyrule];
+  int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
-             pick_yyrule - 1, yylno);
+             yyrule - 1, yylno);
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
@@ -752,19 +765,19 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int pick_yyrule)
 
 # define YY_REDUCE_PRINT(Rule)          \
 do {                                    \
-  if (pick_yydebug)                          \
+  if (yydebug)                          \
     yy_reduce_print (yyssp, yyvsp, Rule); \
 } while (0)
 
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
-int pick_yydebug;
-#else /* !YYDEBUG */
+int yydebug;
+#else /* !PICK_YYDEBUG */
 # define YYDPRINTF(Args)
 # define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !PICK_YYDEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -794,10 +807,10 @@ int pick_yydebug;
 static YYSIZE_T
 yystrlen (const char *yystr)
 {
-  YYSIZE_T pick_yylen;
-  for (pick_yylen = 0; yystr[pick_yylen]; pick_yylen++)
+  YYSIZE_T yylen;
+  for (yylen = 0; yystr[yylen]; yylen++)
     continue;
-  return pick_yylen;
+  return yylen;
 }
 #  endif
 # endif
@@ -812,9 +825,9 @@ static char *
 yystpcpy (char *yydest, const char *yysrc)
 {
   char *yyd = yydest;
-  const char *pick_yys = yysrc;
+  const char *yys = yysrc;
 
-  while ((*yyd++ = *pick_yys++) != '\0')
+  while ((*yyd++ = *yys++) != '\0')
     continue;
 
   return yyd - 1;
@@ -824,7 +837,7 @@ yystpcpy (char *yydest, const char *yysrc)
 
 # ifndef yytnamerr
 /* Copy to YYRES the contents of YYSTR after stripping away unnecessary
-   quotes and backslashes, so that it's suitable for pick_yyerror.  The
+   quotes and backslashes, so that it's suitable for yyerror.  The
    heuristic is that double-quoting is unnecessary unless the string
    contains an apostrophe, a comma, or backslash (other than
    backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
@@ -898,7 +911,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
        the only way this function was invoked is if the default action
        is an error action.  In that case, don't check for expected
        tokens because there are none.
-     - The only way there can be no lookahead present (in pick_yychar) is if
+     - The only way there can be no lookahead present (in yychar) is if
        this state is a consistent state with a default action.  Thus,
        detecting the absence of a lookahead is sufficient to determine
        that there is no unexpected or expected token to report.  In that
@@ -906,7 +919,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
      - Don't assume there isn't a lookahead just because this state is a
        consistent state with a default action.  There might have been a
        previous inconsistent state, consistent state with a non-default
-       action, or user semantic action that manipulated pick_yychar.
+       action, or user semantic action that manipulated yychar.
      - Of course, the expected token list depends on states to have
        correct lookahead information, and it depends on the parser not
        to perform extra reductions after fetching a lookahead from the
@@ -918,7 +931,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
   */
   if (yytoken != YYEMPTY)
     {
-      int yyn = pick_yypact[*yyssp];
+      int yyn = yypact[*yyssp];
       yyarg[yycount++] = yytname[yytoken];
       if (!yypact_value_is_default (yyn))
         {
@@ -926,14 +939,14 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
              YYCHECK.  In other words, skip the first -YYN actions for
              this state because they are default actions.  */
           int yyxbegin = yyn < 0 ? -yyn : 0;
-          /* Stay within bounds of both pick_yycheck and yytname.  */
+          /* Stay within bounds of both yycheck and yytname.  */
           int yychecklim = YYLAST - yyn + 1;
           int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
           int yyx;
 
           for (yyx = yyxbegin; yyx < yyxend; ++yyx)
-            if (pick_yycheck[yyx + yyn] == yyx && yyx != YYTERROR
-                && !yytable_value_is_error (pick_yytable[yyx + yyn]))
+            if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR
+                && !yytable_value_is_error (yytable[yyx + yyn]))
               {
                 if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
                   {
@@ -1027,22 +1040,22 @@ yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
 
 
 /* The lookahead symbol.  */
-int pick_yychar;
+int yychar;
 
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE pick_yylval;
+YYSTYPE yylval;
 /* Number of syntax errors so far.  */
-int pick_yynerrs;
+int yynerrs;
 
 
 /*----------.
-| pick_yyparse.  |
+| yyparse.  |
 `----------*/
 
 int
-pick_yyparse (void)
+yyparse (void)
 {
-    int pick_yystate;
+    int yystate;
     /* Number of tokens to shift before error messages enabled.  */
     int yyerrstatus;
 
@@ -1071,7 +1084,7 @@ pick_yyparse (void)
   int yytoken = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
-  YYSTYPE pick_yyval;
+  YYSTYPE yyval;
 
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
@@ -1084,7 +1097,7 @@ pick_yyparse (void)
 
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
-  int pick_yylen = 0;
+  int yylen = 0;
 
   yyssp = yyss = yyssa;
   yyvsp = yyvs = yyvsa;
@@ -1092,14 +1105,14 @@ pick_yyparse (void)
 
   YYDPRINTF ((stderr, "Starting parse\n"));
 
-  pick_yystate = 0;
+  yystate = 0;
   yyerrstatus = 0;
-  pick_yynerrs = 0;
-  pick_yychar = YYEMPTY; /* Cause a token to be read.  */
+  yynerrs = 0;
+  yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in pick_yystate.  |
+| yynewstate -- Push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
  yynewstate:
   /* In all cases, when you get here, the value and location stacks
@@ -1107,7 +1120,7 @@ pick_yyparse (void)
   yyssp++;
 
  yysetstate:
-  *yyssp = pick_yystate;
+  *yyssp = yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
     {
@@ -1147,8 +1160,8 @@ pick_yyparse (void)
 
       {
         yytype_int16 *yyss1 = yyss;
-        union pick_yyalloc *yyptr =
-          (union pick_yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
+        union yyalloc *yyptr =
+          (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
         if (! yyptr)
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
@@ -1170,9 +1183,9 @@ pick_yyparse (void)
         YYABORT;
     }
 
-  YYDPRINTF ((stderr, "Entering state %d\n", pick_yystate));
+  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
-  if (pick_yystate == YYFINAL)
+  if (yystate == YYFINAL)
     YYACCEPT;
 
   goto yybackup;
@@ -1186,36 +1199,36 @@ yybackup:
      lookahead token if we need one and don't already have one.  */
 
   /* First try to decide what to do without reference to lookahead token.  */
-  yyn = pick_yypact[pick_yystate];
+  yyn = yypact[yystate];
   if (yypact_value_is_default (yyn))
     goto yydefault;
 
   /* Not known => get a lookahead token if don't already have one.  */
 
   /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
-  if (pick_yychar == YYEMPTY)
+  if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
-      pick_yychar = pick_yylex ();
+      yychar = yylex ();
     }
 
-  if (pick_yychar <= YYEOF)
+  if (yychar <= YYEOF)
     {
-      pick_yychar = yytoken = YYEOF;
+      yychar = yytoken = YYEOF;
       YYDPRINTF ((stderr, "Now at end of input.\n"));
     }
   else
     {
-      yytoken = YYTRANSLATE (pick_yychar);
-      YY_SYMBOL_PRINT ("Next token is", yytoken, &pick_yylval, &pick_yylloc);
+      yytoken = YYTRANSLATE (yychar);
+      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
      detect an error, take that action.  */
   yyn += yytoken;
-  if (yyn < 0 || YYLAST < yyn || pick_yycheck[yyn] != yytoken)
+  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
     goto yydefault;
-  yyn = pick_yytable[yyn];
+  yyn = yytable[yyn];
   if (yyn <= 0)
     {
       if (yytable_value_is_error (yyn))
@@ -1230,14 +1243,14 @@ yybackup:
     yyerrstatus--;
 
   /* Shift the lookahead token.  */
-  YY_SYMBOL_PRINT ("Shifting", yytoken, &pick_yylval, &pick_yylloc);
+  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
   /* Discard the shifted token.  */
-  pick_yychar = YYEMPTY;
+  yychar = YYEMPTY;
 
-  pick_yystate = yyn;
+  yystate = yyn;
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  *++yyvsp = pick_yylval;
+  *++yyvsp = yylval;
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   goto yynewstate;
@@ -1247,7 +1260,7 @@ yybackup:
 | yydefault -- do the default action for the current state.  |
 `-----------------------------------------------------------*/
 yydefault:
-  yyn = yydefact[pick_yystate];
+  yyn = yydefact[yystate];
   if (yyn == 0)
     goto yyerrlab;
   goto yyreduce;
@@ -1258,7 +1271,7 @@ yydefault:
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
-  pick_yylen = pick_yyr2[yyn];
+  yylen = yyr2[yyn];
 
   /* If YYLEN is nonzero, implement the default value of the action:
      '$$ = $1'.
@@ -1268,94 +1281,94 @@ yyreduce:
      users should not rely upon it.  Assigning to YYVAL
      unconditionally makes the parser a bit smaller, and it avoids a
      GCC warning that YYVAL may be used uninitialized.  */
-  pick_yyval = yyvsp[1-pick_yylen];
+  yyval = yyvsp[1-yylen];
 
 
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
         case 2:
-#line 59 "pick-gram.y" /* yacc.c:1646  */
+#line 66 "pick-gram.y" /* yacc.c:1646  */
     {
 	     parse_tree = NULL;
 	   }
-#line 1283 "pick-gram.c" /* yacc.c:1646  */
+#line 1296 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 3:
-#line 63 "pick-gram.y" /* yacc.c:1646  */
+#line 70 "pick-gram.y" /* yacc.c:1646  */
     {
 	     parse_tree = (yyvsp[0].node);
 	   }
-#line 1291 "pick-gram.c" /* yacc.c:1646  */
+#line 1304 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 70 "pick-gram.y" /* yacc.c:1646  */
+#line 77 "pick-gram.y" /* yacc.c:1646  */
     {
-	     (pick_yyval.node) = pick_node_create (node_and, (yyvsp[-1].node), (yyvsp[0].node));
+	     (yyval.node) = pick_node_create (node_and, (yyvsp[-1].node), (yyvsp[0].node));
 	   }
-#line 1299 "pick-gram.c" /* yacc.c:1646  */
+#line 1312 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 7:
-#line 77 "pick-gram.y" /* yacc.c:1646  */
+#line 84 "pick-gram.y" /* yacc.c:1646  */
     {
 	     set_cflags ((yyvsp[0].string));
 	   }
-#line 1307 "pick-gram.c" /* yacc.c:1646  */
+#line 1320 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 83 "pick-gram.y" /* yacc.c:1646  */
+#line 90 "pick-gram.y" /* yacc.c:1646  */
     {
-	     int rc = regcomp (&(pick_yyval.regex), (yyvsp[0].string), reg_flags|REG_NOSUB);
+	     int rc = regcomp (&(yyval.regex), (yyvsp[0].string), reg_flags|REG_NOSUB);
 	     if (rc)
 	       {
 		 char errbuf[512];
-		 regerror (rc, &(pick_yyval.regex), errbuf, sizeof (errbuf));
+		 regerror (rc, &(yyval.regex), errbuf, sizeof (errbuf));
 		 mu_error ("error compiling regex \"%s\": %s",
 			   (yyvsp[0].string), errbuf);
 		 YYERROR;
 	       }
 	   }
-#line 1323 "pick-gram.c" /* yacc.c:1646  */
+#line 1336 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 97 "pick-gram.y" /* yacc.c:1646  */
+#line 104 "pick-gram.y" /* yacc.c:1646  */
     {
-	     (pick_yyval.node) = (yyvsp[-1].node);
+	     (yyval.node) = (yyvsp[-1].node);
 	   }
-#line 1331 "pick-gram.c" /* yacc.c:1646  */
+#line 1344 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 101 "pick-gram.y" /* yacc.c:1646  */
+#line 108 "pick-gram.y" /* yacc.c:1646  */
     {
-	     (pick_yyval.node) = pick_node_create (node_regex, (yyvsp[-1].string), regex_dup (&(yyvsp[0].regex)));
+	     (yyval.node) = pick_node_create (node_regex, (yyvsp[-1].string), regex_dup (&(yyvsp[0].regex)));
 	   }
-#line 1339 "pick-gram.c" /* yacc.c:1646  */
+#line 1352 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 105 "pick-gram.y" /* yacc.c:1646  */
+#line 112 "pick-gram.y" /* yacc.c:1646  */
     {
-	     (pick_yyval.node) = pick_node_create (node_regex, NULL, regex_dup (&(yyvsp[0].regex)));
+	     (yyval.node) = pick_node_create (node_regex, NULL, regex_dup (&(yyvsp[0].regex)));
 	   }
-#line 1347 "pick-gram.c" /* yacc.c:1646  */
+#line 1360 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 109 "pick-gram.y" /* yacc.c:1646  */
+#line 116 "pick-gram.y" /* yacc.c:1646  */
     {
-	     (pick_yyval.node) = pick_node_create (node_datefield, (yyvsp[0].string), NULL);
+	     (yyval.node) = pick_node_create (node_datefield, (yyvsp[0].string), NULL);
 	   }
-#line 1355 "pick-gram.c" /* yacc.c:1646  */
+#line 1368 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 113 "pick-gram.y" /* yacc.c:1646  */
+#line 120 "pick-gram.y" /* yacc.c:1646  */
     {
 	     time_t t;
 	     if (mu_parse_date ((yyvsp[0].string), &t, NULL))
@@ -1363,14 +1376,14 @@ yyreduce:
 		 mu_error (_("bad date format: %s"), (yyvsp[0].string));
 		 exit (1);
 	       }
-	     (pick_yyval.node) = pick_node_create (node_before, NULL, NULL);
-	     (pick_yyval.node)->v.time = t;
+	     (yyval.node) = pick_node_create (node_before, NULL, NULL);
+	     (yyval.node)->v.time = t;
 	   }
-#line 1370 "pick-gram.c" /* yacc.c:1646  */
+#line 1383 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 124 "pick-gram.y" /* yacc.c:1646  */
+#line 131 "pick-gram.y" /* yacc.c:1646  */
     {
 	     time_t t;
 	     if (mu_parse_date ((yyvsp[0].string), &t, NULL))
@@ -1378,86 +1391,86 @@ yyreduce:
 		 mu_error (_("bad date format: %s"), (yyvsp[0].string));
 		 exit (1);
 	       }
-	     (pick_yyval.node) = pick_node_create (node_after, NULL, NULL);
-	     (pick_yyval.node)->v.time = t;
+	     (yyval.node) = pick_node_create (node_after, NULL, NULL);
+	     (yyval.node)->v.time = t;
 	   }
-#line 1385 "pick-gram.c" /* yacc.c:1646  */
+#line 1398 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 135 "pick-gram.y" /* yacc.c:1646  */
+#line 142 "pick-gram.y" /* yacc.c:1646  */
     {
-	     (pick_yyval.node) = pick_node_create (node_and, (yyvsp[-2].node), (yyvsp[0].node));
+	     (yyval.node) = pick_node_create (node_and, (yyvsp[-2].node), (yyvsp[0].node));
 	   }
-#line 1393 "pick-gram.c" /* yacc.c:1646  */
+#line 1406 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 139 "pick-gram.y" /* yacc.c:1646  */
+#line 146 "pick-gram.y" /* yacc.c:1646  */
     {
-	     (pick_yyval.node) = pick_node_create (node_or, (yyvsp[-2].node), (yyvsp[0].node));
+	     (yyval.node) = pick_node_create (node_or, (yyvsp[-2].node), (yyvsp[0].node));
 	   }
-#line 1401 "pick-gram.c" /* yacc.c:1646  */
+#line 1414 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 17:
-#line 143 "pick-gram.y" /* yacc.c:1646  */
+#line 150 "pick-gram.y" /* yacc.c:1646  */
     {
-	     (pick_yyval.node) = pick_node_create (node_not, (yyvsp[0].node), NULL);
+	     (yyval.node) = pick_node_create (node_not, (yyvsp[0].node), NULL);
 	   }
-#line 1409 "pick-gram.c" /* yacc.c:1646  */
+#line 1422 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 18:
-#line 149 "pick-gram.y" /* yacc.c:1646  */
+#line 156 "pick-gram.y" /* yacc.c:1646  */
     {
 	     nesting_level++;
 	   }
-#line 1417 "pick-gram.c" /* yacc.c:1646  */
+#line 1430 "pick-gram.c" /* yacc.c:1646  */
     break;
 
   case 19:
-#line 155 "pick-gram.y" /* yacc.c:1646  */
+#line 162 "pick-gram.y" /* yacc.c:1646  */
     {
 	     nesting_level--;
 	   }
-#line 1425 "pick-gram.c" /* yacc.c:1646  */
+#line 1438 "pick-gram.c" /* yacc.c:1646  */
     break;
 
 
-#line 1429 "pick-gram.c" /* yacc.c:1646  */
+#line 1442 "pick-gram.c" /* yacc.c:1646  */
       default: break;
     }
-  /* User semantic actions sometimes alter pick_yychar, and that requires
+  /* User semantic actions sometimes alter yychar, and that requires
      that yytoken be updated with the new translation.  We take the
      approach of translating immediately before every use of yytoken.
      One alternative is translating here after every semantic action,
      but that translation would be missed if the semantic action invokes
-     YYABORT, YYACCEPT, or YYERROR immediately after altering pick_yychar or
+     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
      if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
      incorrect destructor might then be invoked immediately.  In the
      case of YYERROR or YYBACKUP, subsequent parser actions might lead
      to an incorrect destructor call or verbose syntax error message
      before the lookahead is translated.  */
-  YY_SYMBOL_PRINT ("-> $$ =", pick_yyr1[yyn], &pick_yyval, &yyloc);
+  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
 
-  YYPOPSTACK (pick_yylen);
-  pick_yylen = 0;
+  YYPOPSTACK (yylen);
+  yylen = 0;
   YY_STACK_PRINT (yyss, yyssp);
 
-  *++yyvsp = pick_yyval;
+  *++yyvsp = yyval;
 
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
 
-  yyn = pick_yyr1[yyn];
+  yyn = yyr1[yyn];
 
-  pick_yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= pick_yystate && pick_yystate <= YYLAST && pick_yycheck[pick_yystate] == *yyssp)
-    pick_yystate = pick_yytable[pick_yystate];
+  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
+  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
+    yystate = yytable[yystate];
   else
-    pick_yystate = yydefgoto[yyn - YYNTOKENS];
+    yystate = yydefgoto[yyn - YYNTOKENS];
 
   goto yynewstate;
 
@@ -1468,14 +1481,14 @@ yyreduce:
 yyerrlab:
   /* Make sure we have latest lookahead translation.  See comments at
      user semantic actions for why this is necessary.  */
-  yytoken = pick_yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (pick_yychar);
+  yytoken = yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (yychar);
 
   /* If not already recovering from an error, report this error.  */
   if (!yyerrstatus)
     {
-      ++pick_yynerrs;
+      ++yynerrs;
 #if ! YYERROR_VERBOSE
-      pick_yyerror (YY_("syntax error"));
+      yyerror (YY_("syntax error"));
 #else
 # define YYSYNTAX_ERROR yysyntax_error (&yymsg_alloc, &yymsg, \
                                         yyssp, yytoken)
@@ -1502,7 +1515,7 @@ yyerrlab:
                 yymsgp = yymsg;
               }
           }
-        pick_yyerror (yymsgp);
+        yyerror (yymsgp);
         if (yysyntax_error_status == 2)
           goto yyexhaustedlab;
       }
@@ -1517,17 +1530,17 @@ yyerrlab:
       /* If just tried and failed to reuse lookahead token after an
          error, discard it.  */
 
-      if (pick_yychar <= YYEOF)
+      if (yychar <= YYEOF)
         {
           /* Return failure if at end of input.  */
-          if (pick_yychar == YYEOF)
+          if (yychar == YYEOF)
             YYABORT;
         }
       else
         {
           yydestruct ("Error: discarding",
-                      yytoken, &pick_yylval);
-          pick_yychar = YYEMPTY;
+                      yytoken, &yylval);
+          yychar = YYEMPTY;
         }
     }
 
@@ -1549,10 +1562,10 @@ yyerrorlab:
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
-  YYPOPSTACK (pick_yylen);
-  pick_yylen = 0;
+  YYPOPSTACK (yylen);
+  yylen = 0;
   YY_STACK_PRINT (yyss, yyssp);
-  pick_yystate = *yyssp;
+  yystate = *yyssp;
   goto yyerrlab1;
 
 
@@ -1564,13 +1577,13 @@ yyerrlab1:
 
   for (;;)
     {
-      yyn = pick_yypact[pick_yystate];
+      yyn = yypact[yystate];
       if (!yypact_value_is_default (yyn))
         {
           yyn += YYTERROR;
-          if (0 <= yyn && yyn <= YYLAST && pick_yycheck[yyn] == YYTERROR)
+          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
             {
-              yyn = pick_yytable[yyn];
+              yyn = yytable[yyn];
               if (0 < yyn)
                 break;
             }
@@ -1582,21 +1595,21 @@ yyerrlab1:
 
 
       yydestruct ("Error: popping",
-                  yystos[pick_yystate], yyvsp);
+                  yystos[yystate], yyvsp);
       YYPOPSTACK (1);
-      pick_yystate = *yyssp;
+      yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
     }
 
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  *++yyvsp = pick_yylval;
+  *++yyvsp = yylval;
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 
 
   /* Shift the error token.  */
   YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);
 
-  pick_yystate = yyn;
+  yystate = yyn;
   goto yynewstate;
 
 
@@ -1619,23 +1632,23 @@ yyabortlab:
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
 yyexhaustedlab:
-  pick_yyerror (YY_("memory exhausted"));
+  yyerror (YY_("memory exhausted"));
   yyresult = 2;
   /* Fall through.  */
 #endif
 
 yyreturn:
-  if (pick_yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
          user semantic actions for why this is necessary.  */
-      yytoken = YYTRANSLATE (pick_yychar);
+      yytoken = YYTRANSLATE (yychar);
       yydestruct ("Cleanup: discarding lookahead",
-                  yytoken, &pick_yylval);
+                  yytoken, &yylval);
     }
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYABORT or YYACCEPT.  */
-  YYPOPSTACK (pick_yylen);
+  YYPOPSTACK (yylen);
   YY_STACK_PRINT (yyss, yyssp);
   while (yyssp != yyss)
     {
@@ -1653,7 +1666,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 160 "pick-gram.y" /* yacc.c:1906  */
+#line 167 "pick-gram.y" /* yacc.c:1906  */
 
 
 /* Lexical analizer */
@@ -1667,7 +1680,7 @@ struct token
 static mu_iterator_t iterator;
 
 int
-pick_yylex ()
+yylex ()
 {
   struct token *tok;
   
@@ -1675,7 +1688,7 @@ pick_yylex ()
     return 0;
   mu_iterator_current (iterator, (void **)&tok);
   mu_iterator_next (iterator);
-  pick_yylval.string = tok->val;
+  yylval.string = tok->val;
   return tok->tok;
 }
 
@@ -1712,15 +1725,15 @@ tokname (int tok)
 }
 
 int
-pick_yyerror (const char *s)
+yyerror (const char *s)
 {
-  int tok = pick_yylex ();
+  int tok = yylex ();
   const char *str;
   
   if (!tok)
     str = _("end of input");
-  else if (pick_yylval.string)
-    str = pick_yylval.string;
+  else if (yylval.string)
+    str = yylval.string;
   else
     str = tokname (tok);
 
@@ -1763,7 +1776,7 @@ pick_parse (mu_list_t toklist)
   if (mu_list_get_iterator (toklist, &iterator))
     return -1;
   mu_iterator_first (iterator);
-  rc = pick_yyparse ();
+  rc = yyparse ();
   mu_iterator_destroy (&iterator);
   return rc;
 }
