@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2010-2019 Free Software Foundation, Inc.
+   Copyright (C) 2010-2022 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -38,6 +38,9 @@ struct lib_descr {
   int flags;
 } lib_descr[] = {
   { "mbox",    "-lmu_mbox", 0 },
+#ifdef ENABLE_DOTMAIL
+  { "dotmail", "-lmu_dotmail", 0 },
+#endif
 #ifdef ENABLE_MH
   { "mh",      "-lmu_mh",   0 },
 #endif
@@ -52,9 +55,6 @@ struct lib_descr {
   { "pop",    "-lmu_pop",   0 },
   { "pop",    NEEDAUTH,     2 },
 #endif
-#ifdef ENABLE_NNTP  
-  { "nntp",   "-lmu_nntp",  0 },
-#endif
 #ifdef ENABLE_DBM
   { "dbm",    "-lmu_dbm",   0 },
   { "dbm",    DBMLIBS,      2 },
@@ -68,9 +68,10 @@ struct lib_descr {
 #ifdef WITH_PYTHON
   { "python", "-lmu_py " PYTHON_LIBS, -1, NOTALL },
 #endif
-  { "compat", NULL,  0, 0 },  /* deprecated */
-  { "cfg",    NULL,  0, 0 },  /* deprecated */
-  { "argp",   NULL,  0, 0 },  /* deprecated */
+  { "compat" },  /* deprecated */
+  { "cfg"    },  /* deprecated */
+  { "argp"   },  /* deprecated */
+  { "nntp"   },  /* deprecated */
   { NULL }
 };
 
